SystemOrganization addCategory: #'Magma seaside'!

!MagmaLocalLocation methodsFor: '*magma seaside' stamp: 'kph 8/11/2006 03:40'!
newSession
	"For local, we have to determine whether the files are already in-use by another
	local-connection.  If they are, create a new session sharing the original's
	repositoryController, Otherwise open the files."

	| sessionClass |
	sessionClass := self sessionClass.
	^ sessionClass connectedSessions
		maDetect: [ :each | each pathName = path ]
		ifFound: [ :foundSession | sessionClass repositoryController: foundSession repositoryController ]
		ifNone: [ sessionClass openLocal: path ]! !

!MagmaLocalLocation methodsFor: '*magma seaside' stamp: 'kph 6/28/2006 04:21'!
repositoryPath

^FileDirectory default fullNameFor: path! !

!WAConfigurationEditor methodsFor: '*magma seaside' stamp: 'kph 8/14/2006 01:31'!
renderMagmaLocationAttribute: anAttribute on: html

	| location |
	location := configuration valueForAttribute: anAttribute.

	html div id: 'location'; with: [
		html table: [
			location isLocal
				ifTrue: [
					html tableRow: [  
						html tableData id: 'label'; with: 'path:'.
						html tableData: [ html textInput on: #path of: location ]
					]
				] ifFalse: [
					html tableRow: [  
						html tableData id: 'label'; with: 'host'.
						html tableData: [ html textInput on: #host of: location ]
					].
					html tableRow: [  
						html tableData id: 'label'; with: 'port'.
						html tableData: [ html textInput value: location port;
								callback: [:v | location port: v asNumber] ]
					].
				]
		]
	].

	html anchor callback: [ self call: (WAMagmaControlPanel new setLocation: location) ] ; text: '(Magma Control Panel)'.
! !

!WAConfigurationEditor methodsFor: '*magma seaside' stamp: 'kph 6/15/2006 20:33'!
visitMagmaLocationAttribute: anAttribute with: html

	| location |
	location := configuration valueForAttribute: anAttribute. 

	html select 
		list: anAttribute options;
		selected: location class;
		beSubmitOnChange;
		labels: [ :ea | ea name ];
		callback: [ :item | 	(configuration valueAt: #location) class == item
			ifFalse: [ configuration takeValue: item default forAttribute: anAttribute. ]
 		];
		yourself.

	self renderMagmaLocationAttribute: anAttribute on: html.! !

WAComponent subclass: #WAMagmaControlPanel
	instanceVariableNames: 'location magmaSession repositoryControlPanel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaControlPanel commentStamp: 'kph 8/24/2006 02:45' prior: 0!
Architecture:

This control panel expects each application using magma to have its own control panel. Each of these implements #magmaRootClass and #magmaRootDescription which are used to offer the user the ability to create a repository for the application.

Once the repository has been created, with its root object, the control panel is obtained by sending the root object #magmaControlPanelOn:  e.g.

magmaSession root magmaControlPanelOn: magmaSession!

!WAMagmaControlPanel class methodsFor: 'as yet unclassified' stamp: 'kph 8/14/2006 12:09'!
canBeRoot

^true! !

!WAMagmaControlPanel class methodsFor: 'as yet unclassified' stamp: 'kph 8/14/2006 04:15'!
initialize
	self registerAsApplication: 'magma'.! !

!WAMagmaControlPanel class methodsFor: 'as yet unclassified' stamp: 'kph 8/23/2006 19:27'!
newRepository: location

"at present this stats view is available from the configuration editor. The location specified may or may not exist."

^ self new setLocation: location; yourself! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/14/2006 23:21'!
children

^ Array with: repositoryControlPanel! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/15/2006 02:51'!
closeMagmaSession

magmaSession ifNil: [ ^false ].

magmaSession commit.

self location isLocal 
		ifTrue: [ magmaSession disconnectAndClose ]
		ifFalse: [ magmaSession disconnect ].

magmaSession := nil.
repositoryControlPanel := nil.

^true
! !

!WAMagmaControlPanel methodsFor: 'callback actions' stamp: 'kph 8/12/2006 03:18'!
createRepository: repositoryClass

 MagmaRepositoryController create: location path root: repositoryClass new! !

!WAMagmaControlPanel methodsFor: 'callback actions' stamp: 'kph 8/15/2006 05:34'!
deleteRepository

Warning signal: 'Are you sure that you want to delete repository: ', location path.

Warning signal: '(You can still back out) Go ahead and delete repository: ', location path.

(MagmaRepositoryController controllerOpenedOn: location path) ifNotNilDo: [ :mc |  mc close ].

MagmaRepositoryController delete: location path.

magmaSession := nil.! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/24/2006 04:19'!
done

self closeMagmaSession.

self answer! !

!WAMagmaControlPanel methodsFor: 'accessing' stamp: 'kph 8/14/2006 12:17'!
location

^ location! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/24/2006 04:00'!
magmaConnect: aBlock ifAbsent: notThereBlock

[
self magmaSession commitAndBegin.

aBlock value.

] 
	on: MagmaEnvironmentError 
	do: notThereBlock.  ! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/15/2006 02:40'!
magmaSession

^magmaSession ifNil: [ self openMagmaSession ].
! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/24/2006 03:54'!
openMagmaSession

	
	magmaSession := self location isLocal 
		ifTrue: [ MagmaSession openLocal: self location path ]
		ifFalse: [ MagmaSession host: self location host port: self location port ].

	magmaSession connectAs: 'seaside' ; begin.

	 repositoryControlPanel := [ magmaSession root magmaControlPanelOn: magmaSession ] on: Error do: [ nil ].

^magmaSession

! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/24/2006 02:38'!
presentCreateRepositoryOptionsOn: html

	html heading level: 3; with: [ html text:  'options:'].
		html text: 'You may create a repository with one of the following root objects for this application.'.
		html div class: 'repositories'; with: [ 
			html table: [
				((SystemNavigation default allImplementorsOf: #magmaRootClass) collect: [ :m | m actualClass soleInstance ])				
				do: [ :c | 
						html tableRow: [ 
					 			html tableData: [ html bold:  c magmaRootClass name ].
								html tableData: [ html text:   c magmaRootDescription ].
								html tableData: [ html submitButton callback: [ self createRepository: c magmaRootClass ]; text: 'Create'. ]
						] 
					]
				]
			].! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/12/2006 03:28'!
renderAllRepositoryStatsOn: html

	html table: [
		html tableRow: [ 
			html tableHeading: [ html text: 'path' ].
			html tableHeading: [ html text: 'objects' ]. 
			html tableHeading: [ html text: 'clients' ]. 
		].
		MagmaRepositoryController openControllers do: [ :c |
			html tableRow: [
				html tableData: [ html text: c directory pathName ].
				html tableData: [ html text: c objectCount asString ].
				html tableData: [ html text: c numberOfConnectedClients asString ].

			]
		]
	]


 ! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/14/2006 12:23'!
renderContentOn: html

	self renderThisRepositoryStatusOn: html.

	html heading level: 2; with: [ html text: 'Magma Status'].

	self renderAllRepositoryStatsOn: html.! !

!WAMagmaControlPanel methodsFor: 'accessing' stamp: 'kph 8/10/2006 16:38'!
rendererClass
        ^ WARenderCanvas ! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/12/2006 03:37'!
renderLocalPathOn: html

html bold: 'Repository path setting: '.
html text: location path.


! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/23/2006 19:40'!
renderMagmaError: ex on: html

	html break.
	html bold: 'Error: ', ex messageText.
	html break.
	self location isLocal 
		ifTrue: [ self presentCreateRepositoryOptionsOn: html	] 
		ifFalse: [ html text: 'Remote repository not available' ].! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/12/2006 03:38'!
renderRemoteHostOn: html

html bold: 'Repository host: '.
html text: location host , ':' , location port.
! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/15/2006 05:31'!
renderRepositoryOnlineOn: html

	self location isLocal ifTrue: [  html text: '   '. 
		html small: [ html anchor callback: [ self deleteRepository ];text: '(delete)' ]].

	html break.
	html bold: 'Cached Object Count: '.
	html text: magmaSession cachedObjectCount.

	html break.
	html bold: 'Root Object: '.
	html text: magmaSession root asString.
	html horizontalRule.
	html render: repositoryControlPanel.
	html horizontalRule.
! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/24/2006 04:19'!
renderThisRepositoryStatusOn: html

	self location ifNil: [ ^self ].

	html form: [

	html heading level: 2; with: [ html text: 'This Repository:'].

	self location isLocal ifTrue: [ self renderLocalPathOn: html ]
						ifFalse: [ self renderRemoteHostOn: html ].
		
	self magmaConnect: [ self renderRepositoryOnlineOn: html
			] ifAbsent: [ :ex | self renderMagmaError: ex on: html ].
	
	html break.
	html submitButton on: #done of: self.

	].

	html horizontalRule.! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/10/2006 14:04'!
setLocation: l

location := l! !

!WAMagmaControlPanel methodsFor: 'rendering' stamp: 'kph 8/11/2006 14:16'!
style

^ 

'
div.repositories table td {
	border: 1px solid #888;

'! !

WASystemConfiguration subclass: #WAMagmaConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'mmb 12/5/2005 09:17'!
ancestors

	^ Array with: (WARenderLoopConfiguration new)! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 12:17'!
attributes
    "Return the attributes specific to this configuration"

	^ Array with: (WAMagmaLocationAttribute key: #location group: #magma)
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 11:44'!
location

	^ MagmaLocalLocation default
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 11:35'!
repositoryPath

	^ 'store'
! !

!WAMagmaConfiguration methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 11:24'!
sessionClass

	^ WAMagmaSession! !

WAConfigurationAttribute subclass: #WAMagmaLocationAttribute
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaLocationAttribute methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 10:00'!
accept: aVisitor with: anObject

	^ aVisitor visitMagmaLocationAttribute: self with: anObject! !

!WAMagmaLocationAttribute methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 12:13'!
options

	^ MagmaLocation subclasses! !

WASession subclass: #WAMagmaSession
	instanceVariableNames: 'magmaSession'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magma seaside'!

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 12:53'!
commit: aBlock

	self magmaSession commit: aBlock
! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 12:58'!
expire

	super expire.
	magmaSession ifNotNil: [ magmaSession disconnect. magmaSession := nil ]! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 11/4/2005 12:19'!
magmaSession

	^ magmaSession ifNil: [ 
		magmaSession := (self application preferenceAt: #location) newSession.
		magmaSession connectAs: 'seaside'.
		magmaSession ]! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'kph 8/11/2006 03:41'!
repositoryPath
	"This is a convenience method to get the repository directory path from Seaside"

	^ self application preferenceAt: #repositoryPath! !

!WAMagmaSession methodsFor: 'as yet unclassified' stamp: 'brp 10/28/2005 12:52'!
root

	^ self magmaSession root
! !
WAMagmaControlPanel initialize!
